%% Comparison of BWS strategies for SLIP and MR models
%  SW:   Simplest walking model
%  SLIP: Spring-loaded inverted pendulum model
%  MR:   Muslce reflex model
%  - Salil Apte, 2018

clear all
clc

r1 = [228 26 28]./255; % red    - human experimental data for treadmill healthy group
b1 = [55 126 184]./255;% blue   - human experimental data for overground healthy group
g1 = [77 175 74]./255; % green  - muscle reflex model data
o1 = [255 127 0]./255; % orange - SLIP model data
y1 = [255 255 51]./255;% yellow - simplest walking model data
l1 = [152 78 163]./255;% unused

addpath(genpath('superbar-master'))
bws = [0,15,30]; 

%% Stride Length
%bws =  0       15     30
% SLIP model + CF BWS system
SL1  = [1.4126, 1.4546, NaN];
SL1  = SL1./SL1(1);
SL1P = (SL1 - SL1(1))*100;
% SLIP model + CW BWS system 
SL2 = [NaN,NaN,NaN];
% SLIP model + TS BWS system 
SL3 = [1.4126,1.4793,1.5821];
SL3 = SL3/SL3(1);
SL3P = (SL3 - SL3(1))*100;
% MR model + CF BWS system
SL4 = [1.5925,1.5025,1.4050];
SL4 = SL4/SL4(1);
SL4P = (SL4 - SL4(1))*100;
% MR model + CW BWS system
SL5 = [1.5975,1.4925,1.2500];
SL5 = SL5/SL5(1);
SL5P = (SL5 - SL5(1))*100;
% MR model + TS BWS system
SL6 = [1.5912,1.5300,1.4213];
SL6 = SL6/SL6(1);
SL6P = (SL6 - SL6(1))*100;

SL = [SL1;SL2;SL3;SL4;SL5;SL6]';
SLP = [SL1P;SL3P;SL4P;SL5P;SL6P];
% SL = [SL1;SL2]';

Colour = [r1;r1;r1;b1;b1;b1];

figure 
superbar(bws,SL, 'BarFaceColor', permute(Colour, [6 1 2 3 4 5]), 'BarWidth',10);
grid on
grid minor
axis([-5 35 0.5 1.5])
set(gca,'fontsize',36)
xticks([0 15 30])
xticklabels({ '0', '15', '30'})
ylabel('Stride Length','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')

%% Cadence
%bws =  0       15     30
% SLIP model + CF BWS system
C1  = [1.6667, 1.6000, NaN];
C1  = C1./C1(1);
C1P = (C1 - C1(1))*100;
% SLIP model + CW BWS system 
C2 = [NaN,NaN,NaN];
% SLIP model + TS BWS system 
C3 = [1.6667,1.6000,1.5333];
C3 = C3/C3(1);
C3P = (C3 - C3(1))*100;
% MR model + CF BWS system
C4 = [1.7149,1.4414,1.3536];
C4 = C4/C4(1);
C4P = (C4 - C4(1))*100;
% MR model + CW BWS system
C5 = [1.7241,1.4311,1.3267];
C5 = C5/C5(1);
C5P = (C5 - C5(1))*100;
% MR model + TS BWS system
C6 = [1.7112,1.4519,1.3617];
C6 = C6/C6(1);
C6P = (C6 - C6(1))*100;

C = [C1;C2;C3;C4;C5;C6]';
CP = [C1P;C3P;C4P;C5P;C6P];
% C = [C1;C2]';

Colour = [r1;r1;r1;b1;b1;b1];

figure 
superbar(bws,C, 'BarFaceColor', permute(Colour, [6 1 2 3 4 5]), 'BarWidth',10);
grid on
grid minor
axis([-5 35 0.5 1.5])
set(gca,'fontsize',36)
xticks([0 15 30])
xticklabels({ '0', '15', '30'})
ylabel('Cadence','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')

%% Walking speed
%bws =  0       15     30
% SLIP model + CF BWS system
WS1  = [1.1772, 1.1637, NaN];
WS1  = WS1./WS1(1);
WS1P = (WS1 - WS1(1))*100;
% SLIP model + CW BWS system 
WS2 = [NaN,NaN,NaN];
% SLIP model + TS BWS system 
WS3 = [1.1772,1.1835,1.1602];
WS3 = WS3/WS3(1);
WS3P = (WS3 - WS3(1))*100;
% MR model + CF BWS system
WS4 = [1.3626,1.0825,0.9134];
WS4 = WS4/WS4(1);
WS4P = (WS4 - WS4(1))*100;
% MR model + CW BWS system
WS5 = [1.3720,1.0677,0.9370];
WS5 = WS5/WS5(1);
WS5P = (WS5 - WS5(1))*100;
% MR model + TS BWS system
WS6 = [1.3614,1.1140,0.9679];
WS6 = WS6/WS6(1);
WS6P = (WS6 - WS6(1))*100;

WS = [WS1;WS2;WS3;WS4;WS5;WS6]';
WSP = [WS1P;WS3P;WS4P;WS5P;WS6P];
% WS = [WS1;WS2]';

Colour = [r1;r1;r1;b1;b1;b1];

figure 
superbar(bws,WS, 'BarFaceColor', permute(Colour, [6 1 2 3 4 5]), 'BarWidth',10);
grid on
grid minor
axis([-5 35 0.5 1.5])
set(gca,'fontsize',36)
xticks([0 15 30])
xticklabels({ '0', '15', '30'})
ylabel('Walking speed','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')

%% Single limb stance

%BWS =  0       15     30
% SLIP model + CF BWS system
SLS1  = [21.8913, 23.3491, NaN];
SLS1  = SLS1./SLS1(1);
SLS1P = (SLS1 - SLS1(1))*100;
% SLIP model + CW BWS system 
SLS2 = [NaN,NaN,NaN];
% SLIP model + TS BWS system 
SLS3 = [21.8913,21.982,26.2497];
SLS3 = SLS3/SLS3(1);
SLS3P = (SLS3 - SLS3(1))*100;
% MR model + CF BWS system
SLS4 = [38.8532,41.1249,41.8347];
SLS4 = SLS4/SLS4(1);
SLS4P = (SLS4 - SLS4(1))*100;
% MR model + CW BWS system
SLS5 = [37.3914,40.7416,41.7911];
SLS5 = SLS5/SLS5(1);
SLS5P = (SLS5 - SLS5(1))*100;
% MR model + TS BWS system
SLS6 = [39.1437,41.6514,41.8297];
SLS6 = SLS6/SLS6(1);
SLS6P = (SLS6 - SLS6(1))*100;

SLS = [SLS1;SLS2;SLS3;SLS4;SLS5;SLS6]';
SLSP = [SLS1P;SLS3P;SLS4P;SLS5P;SLS6P];
% SLS = [SLS1;SLS2]';

Colour = [r1;r1;r1;b1;b1;b1];

figure 
superbar(bws,SLS, 'BarFaceColor', permute(Colour, [6 1 2 3 4 5]), 'BarWidth',10);
grid on
grid minor
axis([-5 35 0.5 1.5])
set(gca,'fontsize',36)
xticks([0 15 30])
xticklabels({ '0', '15', '30'})
ylabel('Single limb stance','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')

%% Double limb stance

%BWS =  0       15     30
% SLIP model + CF BWS system
DLS1  = [14.5580, 13.2727, NaN];
DLS1  = DLS1./DLS1(1);
DLS1P = (DLS1 - DLS1(1))*100;
% SLIP model + CW BWS system 
DLS2 = [NaN,NaN,NaN];
% SLIP model + TS BWS system 
DLS3 = [14.5580,13.4643,9.2854];
DLS3 = DLS3/DLS3(1);
DLS3P = (DLS3 - DLS3(1))*100;
% MR model + CF BWS system
DLS4 = [11.0397,8.8736,8.1216];
DLS4 = DLS4/DLS4(1);
DLS4P = (DLS4 - DLS4(1))*100;
% MR model + CW BWS system
DLS5 = [11.5299,8.7655,8.1260];
DLS5 = DLS5/DLS5(1);
DLS5P = (DLS5 - DLS5(1))*100;
% MR model + TS BWS system
DLS6 = [10.9089,8.6207,8.1702];
DLS6 = DLS6/DLS6(1);
DLS6P = (DLS6 - DLS6(1))*100;

DLS = [DLS1;DLS2;DLS3;DLS4;DLS5;DLS6]';
DLSP = [DLS1P;DLS3P;DLS4P;DLS5P;DLS6P];
% DLS = [DLS1;DLS2]';

Colour = [r1;r1;r1;b1;b1;b1];

figure 
superbar(bws,DLS, 'BarFaceColor', permute(Colour, [6 1 2 3 4 5]), 'BarWidth',10);
grid on
grid minor
axis([-5 35 0.5 1.5])
set(gca,'fontsize',36)
xticks([0 15 30])
xticklabels({ '0', '15', '30'})
ylabel('Double limb stance','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')

%% Total stance phase

%BWS =  0       15     30
% SLIP model + CF BWS system
ST1  = [51.0072, 49.4945, NaN];
ST1  = ST1./ST1(1);
ST1P = (ST1 - ST1(1))*100;
% SLIP model + CW BWS system 
ST2 = [NaN,NaN,NaN];
% SLIP model + TS BWS system 
ST3 = [51.0072,48.8669,44.8205];
ST3 = ST3/ST3(1);
ST3P = (ST3 - ST3(1))*100;
% MR model + CF BWS system
ST4 = [60.9325,58.8722,58.0779];
ST4 = ST4/ST4(1);
ST4P = (ST4 - ST4(1))*100;
% MR model + CW BWS system
ST5 = [60.4513,58.2726,58.0431];
ST5 = ST5/ST5(1);
ST5P = (ST5 - ST5(1))*100;
% MR model + TS BWS system
ST6 = [60.9615,58.8927,58.1701];
ST6 = ST6/ST6(1);
ST6P = (ST6 - ST6(1))*100;

ST = [ST1;ST2;ST3;ST4;ST5;ST6]';
STP = [ST1P;ST3P;ST4P;ST5P;ST6P];
% ST = [ST1;ST2]';

Colour = [r1;r1;r1;b1;b1;b1];

figure 
superbar(bws,ST, 'BarFaceColor', permute(Colour, [6 1 2 3 4 5]), 'BarWidth',10);
grid on
grid minor
axis([-5 35 0.5 1.5])
set(gca,'fontsize',36)
xticks([0 15 30])
xticklabels({ '0', '15', '30'})
ylabel('Total stance','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')

%% Vertical GRF peak I

%BWS =  0       15     30
% SLIP model + CF BWS system
V1G1  = [1952.7, 1708.5, NaN];
V1G1  = V1G1./V1G1(1);
V1G1P = (V1G1 - V1G1(1))*100;
% SLIP model + CW BWS system 
V1G2 = [NaN,NaN,NaN];
% SLIP model + TS BWS system 
V1G3 = [1953.4,1724.7,1436.7];
V1G3 = V1G3/V1G3(1);
V1G3P = (V1G3 - V1G3(1))*100;
% MR model + CF BWS system
V1G4 = [13.4075,10.1313,8.4750];
V1G4 = V1G4/V1G4(1);
V1G4P = (V1G4 - V1G4(1))*100;
% MR model + CW BWS system
V1G5 = [13.4100,10.1529,8.9163];
V1G5 = V1G5/V1G5(1);
V1G5P = (V1G5 - V1G5(1))*100;
% MR model + TS BWS system
V1G6 = [13.3625,10.3013,8.5187];
V1G6 = V1G6/V1G6(1);    
V1G6P = (V1G6 - V1G6(1))*100;

V1G = [V1G1;V1G2;V1G3;V1G4;V1G5;V1G6]';
V1GP = [V1G1P;V1G3P;V1G4P;V1G5P;V1G6P];
% V1G = [V1G1;V1G2]';

Colour = [r1;r1;r1;b1;b1;b1];

figure 
superbar(bws,V1G, 'BarFaceColor', permute(Colour, [6 1 2 3 4 5]), 'BarWidth',10);
grid on
grid minor
axis([-5 35 0.5 1.5])
set(gca,'fontsize',36)
xticks([0 15 30])
xticklabels({ '0', '15', '30'})
ylabel('Vertical GRF peak I','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')

%% Vertical GRF peak II

%BWS =  0       15     30
% SLIP model + CF BWS system
V2G1  = [1939.0, 1707.6, NaN];
V2G1  = V2G1./V2G1(1);
V2G1P = (V2G1 - V2G1(1))*100;
% SLIP model + CW BWS system 
V2G2 = [NaN,NaN,NaN];
% SLIP model + TS BWS system 
V2G3 = [1950.0,1720.9,1461.8];
V2G3 = V2G3/V2G3(1);
V2G3P = (V2G3 - V2G3(1))*100;
% MR model + CF BWS system
V2G4 = [10.4450,9.4438,8.4300];
V2G4 = V2G4/V2G4(1);
V2G4P = (V2G4 - V2G4(1))*100;
% MR model + CW BWS system
V2G5 = [10.2900,9.3157,8.4438];
V2G5 = V2G5/V2G5(1);
V2G5P = (V2G5 - V2G5(1))*100;
% MR model + TS BWS system
V2G6 = [10.4725,9.6638,9.2325];
V2G6 = V2G6/V2G6(1);
V2G6P = (V2G6 - V2G6(1))*100;

V2G = [V2G1;V2G2;V2G3;V2G4;V2G5;V2G6]';
V2GP = [V2G1P;V2G3P;V2G4P;V2G5P;V2G6P];
% V2G = [V2G1;V2G2]';

Colour = [r1;r1;r1;b1;b1;b1];

figure 
superbar(bws,V2G, 'BarFaceColor', permute(Colour, [6 1 2 3 4 5]), 'BarWidth',10);
grid on
grid minor
axis([-5 35 0.5 1.5])
set(gca,'fontsize',36)
xticks([0 15 30])
xticklabels({ '0', '15', '30'})
ylabel('Vertical GRF peak II','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')