%% Comparison of BWS systems using RMS error 
%  Gait data up to 30% BWS is considered
%  Missing data points are assigned a value of 0 so as to obtain a RMS error
%  of 100% since this indicates the strongest deviation from stable walking
%  at 0% BWU.
%  SW:   Simplest walking model
%  SLIP: Spring-loaded inverted pendulum model
%  MR:   Muslce reflex model
%  Function 'rmse.m' is used to calculate the rmse values
%  - Salil Apte, 2018

clear all
clc
%% Stride length

% Constant force BWS
SL_SW_CF       = [1.4240;1.4426;1.4562;0;0;0;0];
SL_SW_CF       = SL_SW_CF/SL_SW_CF(1);
rms_SL_SW_CF   = rmse(SL_SW_CF);
SL_SLIP_CF     = [1.4126;1.4505;1.4650;1.4546;0;0;0];
SL_SLIP_CF     = SL_SLIP_CF/SL_SLIP_CF(1);
rms_SL_SLIP_CF = rmse(SL_SLIP_CF);
SL_MR_CF       = [1.5925;1.5737;1.6041;1.5025;1.3838;1.4412;1.4050];
SL_MR_CF       = SL_MR_CF/SL_MR_CF(1);
rms_SL_MR_CF   = rmse(SL_MR_CF);

% Counterweight BWS
SL_SW_CW       = [1.4240;1.4560;0;0;0;0;0];
SL_SW_CW       = SL_SW_CW/SL_SW_CW(1);
rms_SL_SW_CW   = rmse(SL_SW_CW);
SL_SLIP_CW     = [1;0;0;0;0;0;0]; % SLIP model did not walk at >0% BWU for the CW system
SL_SLIP_CW     = SL_SLIP_CW/SL_SLIP_CW(1);
rms_SL_SLIP_CW = rmse(SL_SLIP_CW);
SL_MR_CW       = [1.5975;1.5575;1.5175;1.4925;1.4725;0;1.2500];
SL_MR_CW       = SL_MR_CW/SL_MR_CW(1);
rms_SL_MR_CW   = rmse(SL_MR_CW);

% Tuned spring BWS
SL_SW_TS       = [1.4240;1.4429;1.4530;0;0;0;0];
SL_SW_TS       = SL_SW_TS/SL_SW_TS(1);
rms_SL_SW_TS   = rmse(SL_SW_TS);
SL_SLIP_TS     = [1.4126;1.4559;1.4830;1.4793;1.5248;1.5324;1.5821];
SL_SLIP_TS     = SL_SLIP_TS/SL_SLIP_TS(1);
rms_SL_SLIP_TS = rmse(SL_SLIP_TS);
SL_MR_TS       = [1.5912;1.5943;1.5986;1.5300;1.5012;1.4633;1.4213];
SL_MR_TS       = SL_MR_TS/SL_MR_TS(1);
rms_SL_MR_TS   = rmse(SL_MR_TS);

SL_rms        = [rms_SL_SW_CF,rms_SL_SLIP_CF,rms_SL_MR_CF;
                  rms_SL_SW_CW,rms_SL_SLIP_CW,rms_SL_MR_CW;
                  rms_SL_SW_TS,rms_SL_SLIP_TS,rms_SL_MR_TS]';

%% Cadence

% Constant force BWS
C_SW_CF       = [0.2774;0.2754;0.2815;0;0;0;0];
C_SW_CF       = C_SW_CF/C_SW_CF(1);
rms_C_SW_CF   = rmse(C_SW_CF);
C_SLIP_CF     = [1.6667;1.6000;1.6000;1.6000;0;0;0];
C_SLIP_CF     = C_SLIP_CF/C_SLIP_CF(1);
rms_C_SLIP_CF = rmse(C_SLIP_CF);
C_MR_CF       = [1.7149;1.6327;1.5038;1.4414;1.4035;1.3746;1.3536];
C_MR_CF       = C_MR_CF/C_MR_CF(1);
rms_C_MR_CF   = rmse(C_MR_CF);

% Counterweight BWS
C_SW_CW       = [0.2774;0.2811;0;0;0;0;0];
C_SW_CW       = C_SW_CW/C_SW_CW(1);
rms_C_SW_CW   = rmse(C_SW_CW);
C_SLIP_CW     = [1;0;0;0;0;0;0]; % SLIP model did not walk at >0% BWU for the CW system
C_SLIP_CW     = C_SLIP_CW/C_SLIP_CW(1);
rms_C_SLIP_CW = rmse(C_SLIP_CW);
C_MR_CW       = [1.7241;1.5936;1.4842;1.4311;1.3889;0;1.3267];
C_MR_CW       = C_MR_CW/C_MR_CW(1);
rms_C_MR_CW   = rmse(C_MR_CW);

% Tuned spring BWS
C_SW_TS       = [0.2774;0.2754;0.2832;0;0;0;0];
C_SW_TS       = C_SW_TS/C_SW_TS(1);
rms_C_SW_TS   = rmse(C_SW_TS);
C_SLIP_TS     = [1.6667;1.6000;1.6000;1.6000;1.5333;1.5333;1.5333];
C_SLIP_TS     = C_SLIP_TS/C_SLIP_TS(1);
rms_C_SLIP_TS = rmse(C_SLIP_TS
C_MR_TS       = [1.7112;1.6931;1.6771;1.4519;1.4172;1.3944;1.3617]; % low-pass filtered
C_MR_TS       = C_MR_TS/C_MR_TS(1);
rms_C_MR_TS   = rmse(C_MR_TS);

C_rms        = [rms_C_SW_CF,rms_C_SLIP_CF,rms_C_MR_CF;
                rms_C_SW_CW,rms_C_SLIP_CW,rms_C_MR_CW;
                rms_C_SW_TS,rms_C_SLIP_TS,rms_C_MR_TS]';

%% Walking speed

% Constant force BWS
WS_SW_CF       = [0.0248;0.0247;0.0257;0;0;0;0];
WS_SW_CF       = WS_SW_CF/WS_SW_CF(1);
rms_WS_SW_CF   = rmse(WS_SW_CF);
WS_SLIP_CF     = [1.1772;1.1604;1.1720;1.1637;0;0;0];
WS_SLIP_CF     = WS_SLIP_CF/WS_SLIP_CF(1);
rms_WS_SLIP_CF = rmse(WS_SLIP_CF);
WS_MR_CF       = [1.3626;1.2864;1.1550;1.0825;1.0368;1.0080;0.9134];
WS_MR_CF       = WS_MR_CF/WS_MR_CF(1);
rms_WS_MR_CF   = rmse(WS_MR_CF);

% Counterweight BWS
WS_SW_CW       = [0.0248;0.0258;0;0;0;0;0];
WS_SW_CW       = WS_SW_CW/WS_SW_CW(1);
rms_WS_SW_CW   = rmse(WS_SW_CW);
WS_SLIP_CW     = [1;0;0;0;0;0;0]; % SLIP model did not walk at >0% BWU for the CW system
WS_SLIP_CW     = WS_SLIP_CW/WS_SLIP_CW(1);
rms_WS_SLIP_CW = rmse(WS_SLIP_CW);
WS_MR_CW       = [1.3720;1.2448;1.1242;1.0677;1.0242;0;0.9370];
WS_MR_CW       = WS_MR_CW/WS_MR_CW(1);
rms_WS_MR_CW   = rmse(WS_MR_CW);

% Tuned spring BWS
WS_SW_TS       = [0.0248;0.0248;0.0252;0;0;0;0];
WS_SW_TS       = WS_SW_TS/WS_SW_TS(1);
rms_WS_SW_TS   = rmse(WS_SW_TS);
WS_SLIP_TS     = [1.1772;1.1647;1.1827;1.1835;1.1690;1.1749;1.1602];
WS_SLIP_TS     = WS_SLIP_TS/WS_SLIP_TS(1);
rms_WS_SLIP_TS = rmse(WS_SLIP_TS);
WS_MR_TS       = [1.3614;1.3551;1.3348;1.1140;1.0629;1.0180;0.9679]; 
WS_MR_TS       = WS_MR_TS/WS_MR_TS(1);
rms_WS_MR_TS   = rmse(WS_MR_TS);

WS_rms        = [rms_WS_SW_CF,rms_WS_SLIP_CF,rms_WS_MR_CF;
                rms_WS_SW_CW,rms_WS_SLIP_CW,rms_WS_MR_CW;
                rms_WS_SW_TS,rms_WS_SLIP_TS,rms_WS_MR_TS]';
%% Single limb stance

% Constant force BWS
SLS_SLIP_CF     = [21.8913;21.7673;21.6730;23.3491;0;0;0];
SLS_SLIP_CF     = SLS_SLIP_CF/SLS_SLIP_CF(1);
rms_SLS_SLIP_CF = rmse(SLS_SLIP_CF);
SLS_MR_CF       = [38.8532;40.0522;40.7436;41.1259;41.4920;41.7964;41.8347];
SLS_MR_CF       = SLS_MR_CF/SLS_MR_CF(1);
rms_SLS_MR_CF   = rmse(SLS_MR_CF);

% Counterweight BWS
SLS_SLIP_CW     = [1;0;0;0;0;0;0]; % SLIP model did not walk at >0% BWU for the CW system
SLS_SLIP_CW     = SLS_SLIP_CW/SLS_SLIP_CW(1);
rms_SLS_SLIP_CW = rmse(SLS_SLIP_CW);
SLS_MR_CW       = [37.3914;40.2882;40.8619;40.7416;41.6670;0;41.7911];
SLS_MR_CW       = SLS_MR_CW/SLS_MR_CW(1);
rms_SLS_MR_CW   = rmse(SLS_MR_CW);

% Tuned spring BWS
SLS_SLIP_TS     = [21.8913;21.9382;22.9491;21.9382;24.3143;25.7710;26.2497];
SLS_SLIP_TS     = SLS_SLIP_TS/SLS_SLIP_TS(1);
rms_SLS_SLIP_TS = rmse(SLS_SLIP_TS);
SLS_MR_TS       = [39.1437;39.4175;39.6739;41.6514;41.4974;41.7884;41.8297]; 
SLS_MR_TS       = SLS_MR_TS/SLS_MR_TS(1);
rms_SLS_MR_TS   = rmse(SLS_MR_TS);

SLS_rms        = [rms_SLS_SLIP_CF,rms_SLS_MR_CF;
                rms_SLS_SLIP_CW,rms_SLS_MR_CW;
                rms_SLS_SLIP_TS,rms_SLS_MR_TS]';

%% Initial double limb stance

% Constant force BWS
DLS_SLIP_CF     = [14.5580;13.7461;13.5165;13.2727;0;0;0];
DLS_SLIP_CF     = DLS_SLIP_CF/DLS_SLIP_CF(1);
rms_DLS_SLIP_CF = rmse(DLS_SLIP_CF);
DLS_MR_CF       = [11.0397;9.9493;9.2108;8.8736;8.5087;8.2476;8.1216];
DLS_MR_CF       = DLS_MR_CF/DLS_MR_CF(1);
rms_DLS_MR_CF   = rmse(DLS_MR_CF);

% Counterweight BWS
DLS_SLIP_CW     = [1;0;0;0;0;0;0]; % SLIP model did not walk at >0% BWU for the CW system
DLS_SLIP_CW     = DLS_SLIP_CW/DLS_SLIP_CW(1);
rms_DLS_SLIP_CW = rmse(DLS_SLIP_CW);
DLS_MR_CW       = [11.5299;9.6612;9.1371;8.7655;8.3334;0;8.1260];
DLS_MR_CW       = DLS_MR_CW/DLS_MR_CW(1);
rms_DLS_MR_CW   = rmse(DLS_MR_CW);

% Tuned spring BWS
DLS_SLIP_TS     = [14.5580;13.4643;12.9078;13.4643;11.1968;10.4778;9.2854];
DLS_SLIP_TS     = DLS_SLIP_TS/DLS_SLIP_TS(1);
rms_DLS_SLIP_TS = rmse(DLS_SLIP_TS);
DLS_MR_TS       = [10.9089;10.6348;10.5343;8.6207;8.5032;8.3228;8.1702]; 
DLS_MR_TS       = DLS_MR_TS/DLS_MR_TS(1);
rms_DLS_MR_TS   = rmse(DLS_MR_TS);

DLS_rms        = [rms_DLS_SLIP_CF,rms_DLS_MR_CF;
                rms_DLS_SLIP_CW,rms_DLS_MR_CW;
                rms_DLS_SLIP_TS,rms_DLS_MR_TS]';

%% Total stance phase

% Constant force BWS
ST_SW_CF       = [3.6055;3.6310;3.5519;0;0;0;0];
ST_SW_CF       = ST_SW_CF/ST_SW_CF(1);
rms_ST_SW_CF   = rmse(ST_SW_CF);
ST_SLIP_CF     = [51.0072;49.2594;48.7061;49.4945;0;0;0];
ST_SLIP_CF     = ST_SLIP_CF/ST_SLIP_CF(1);
rms_ST_SLIP_CF = rmse(ST_SLIP_CF);
ST_MR_CF       = [60.9325;59.9507;59.1651;58.8722;58.5084;58.2916;58.0779];
ST_MR_CF       = ST_MR_CF/ST_MR_CF(1);
rms_ST_MR_CF   = rmse(ST_MR_CF);

% Counterweight BWS
ST_SW_CW       = [3.6055;3.5572;0;0;0;0;0];
ST_SW_CW       = ST_SW_CW/ST_SW_CW(1);
rms_ST_SW_CW   = rmse(ST_SW_CW);
ST_SLIP_CW     = [1;0;0;0;0;0;0]; % SLIP model did not walk at >0% BWU for the CW system
ST_SLIP_CW     = ST_SLIP_CW/ST_SLIP_CW(1);
rms_ST_SLIP_CW = rmse(ST_SLIP_CW);
ST_MR_CW       = [60.4513;59.6106;59.1361;58.2726;58.3338;0;58.0431];
ST_MR_CW       = ST_MR_CW/ST_MR_CW(1);
rms_ST_MR_CW   = rmse(ST_MR_CW);

% Tuned spring BWS
ST_SW_TS       = [3.6055;3.6310;3.5308;0;0;0;0];
ST_SW_TS       = ST_SW_TS/ST_SW_TS(1);
rms_ST_SW_TS   = rmse(ST_SW_TS);
ST_SLIP_TS     = [51.0072;48.8669;48.7647;48.8669;46.7079;46.7265;44.8205];
ST_SLIP_TS     = ST_SLIP_TS/ST_SLIP_TS(1);
rms_ST_SLIP_TS = rmse(ST_SLIP_TS);
ST_MR_TS       = [60.9615;60.6871;60.7425;58.8927;58.5038;58.4341;58.1701]; 
ST_MR_TS       = ST_MR_TS/ST_MR_TS(1);
rms_ST_MR_TS   = rmse(ST_MR_TS);

ST_rms        = [rms_ST_SW_CF,rms_ST_SLIP_CF,rms_ST_MR_CF;
                rms_ST_SW_CW,rms_ST_SLIP_CW,rms_ST_MR_CW;
                rms_ST_SW_TS,rms_ST_SLIP_TS,rms_ST_MR_TS]';
            
%% Hip angle - ROM

% Constant force BWS
HK_MR_CF       = [53.5125;51.2375;49.0900;49.2788;49.4725;49.5175;49.2125];
HK_MR_CF       = HK_MR_CF/HK_MR_CF(1);
rms_HK_MR_CF   = rmse(HK_MR_CF);

% Counterweight BWS
HK_MR_CW       = [53.6550;50.5475;49.5513;49.7862;49.9550;0;50.0150];
HK_MR_CW       = HK_MR_CW/HK_MR_CW(1);
rms_HK_MR_CW   = rmse(HK_MR_CW);

% Tuned spring BWS
HK_MR_TS       = [53.3100;52.4625;51.5112;49.3925;49.3637;49.3813;49.3812]; 
HK_MR_TS       = HK_MR_TS/HK_MR_TS(1);
rms_HK_MR_TS   = rmse(HK_MR_TS);

HK_rms        = [rms_HK_MR_CF;
                 rms_HK_MR_CW;
                 rms_HK_MR_TS]';

%% Knee angle - ROM

% Constant force BWS
KK_MR_CF       = [67.7825;64.3850;58.6863;56.8962;55.9437;55.3738;54.8218];
KK_MR_CF       = KK_MR_CF/KK_MR_CF(1);
rms_KK_MR_CF   = rmse(KK_MR_CF);

% Counterweight BWS
KK_MR_CW       = [68.7100;63.5800;59.5925;58.0163;56.5425;0;55.4288];
KK_MR_CW       = KK_MR_CW/KK_MR_CW(1);
rms_KK_MR_CW   = rmse(KK_MR_CW);

% Tuned spring BWS
KK_MR_TS       = [67.6088;65.1475;62.1550;55.3025;54.5125;54.5213;54.9838]; 
KK_MR_TS       = KK_MR_TS/KK_MR_TS(1);
rms_KK_MR_TS   = rmse(KK_MR_TS);

KK_rms        = [rms_KK_MR_CF;
                 rms_KK_MR_CW;
                 rms_KK_MR_TS]';
             
%% Ankle angle - ROM

% Constant force BWS
AK_MR_CF       = [33.4025;30.4413;27.4288;25.9925;25.1088;24.5375;23.9063];
AK_MR_CF       = AK_MR_CF/AK_MR_CF(1);
rms_AK_MR_CF   = rmse(AK_MR_CF);

% Counterweight BWS
AK_MR_CW       = [34.3263;29.7900;27.1987;25.7750;24.7287;0;22.8563];
AK_MR_CW       = AK_MR_CW/AK_MR_CW(1);
rms_AK_MR_CW   = rmse(AK_MR_CW);

% Tuned spring BWS
AK_MR_TS       = [33.2730;31.3118;29.4363;26.2025;25.4213;24.8300;24.1625]; 
AK_MR_TS       = AK_MR_TS/AK_MR_TS(1);
rms_AK_MR_TS   = rmse(AK_MR_TS);

AK_rms        = [rms_AK_MR_CF;
                 rms_AK_MR_CW;
                 rms_AK_MR_TS]';
             
%% Hip extension moment

% Constant force BWS
HME_MR_CF       = [1.9537;1.7375;1.4813;1.5425;1.5350;1.4938;1.4088];
HME_MR_CF       = HME_MR_CF/HME_MR_CF(1);
rms_HME_MR_CF   = rmse(HME_MR_CF);

% Counterweight BWS
HME_MR_CW       = [1.9688;1.6688;1.5650;1.6471;1.6637;0;1.5075];
HME_MR_CW       = HME_MR_CW/HME_MR_CW(1);
rms_HME_MR_CW   = rmse(HME_MR_CW);

% Tuned spring BWS
HME_MR_TS       = [1.9350;1.8575;1.7775;1.5625;1.4850;1.4563;1.4012]; 
HME_MR_TS       = HME_MR_TS/HME_MR_TS(1);
rms_HME_MR_TS   = rmse(HME_MR_TS);

HME_rms        = [rms_HME_MR_CF;
                 rms_HME_MR_CW;
                 rms_HME_MR_TS]';
             
%% Hip flexion moment

% Constant force BWS
HMF_MR_CF       = [-0.8263;-0.7313;-0.7613;-0.7888;-0.7963;-0.7788;-0.7562];
HMF_MR_CF       = HMF_MR_CF/HMF_MR_CF(1);
rms_HMF_MR_CF   = rmse(HMF_MR_CF);

% Counterweight BWS
HMF_MR_CW       = [-0.9375;-0.7213;-0.7413;-0.7500;-0.7637;0;-0.6825];
HMF_MR_CW       = HMF_MR_CW/HMF_MR_CW(1);
rms_HMF_MR_CW   = rmse(HMF_MR_CW);

% Tuned spring BWS
HMF_MR_TS       = [-0.8113;-0.7725;-0.7500;-0.8550;-0.8725;-0.8563;-0.7962]; 
HMF_MR_TS       = HMF_MR_TS/HMF_MR_TS(1);
rms_HMF_MR_TS   = rmse(HMF_MR_TS);

HMF_rms        = [rms_HMF_MR_CF;
                 rms_HMF_MR_CW;
                 rms_HMF_MR_TS]';
             
%% Knee extension moment

% Constant force BWS
KME_MR_CF       = [0.3825;0.2663;0.2750;0.2810;0.2663;0.2425;0.2238];
KME_MR_CF       = KME_MR_CF/KME_MR_CF(1);
rms_KME_MR_CF   = rmse(KME_MR_CF);

% Counterweight BWS
KME_MR_CW       = [0.4313;0.2150;0.2325;0.2443;0.2638;0;0.2025];
KME_MR_CW       = KME_MR_CW/KME_MR_CW(1);
rms_KME_MR_CW   = rmse(KME_MR_CW);

% Tuned spring BWS
KME_MR_TS       = [0.3662;0.3625;0.3538;0.3200;0.3000;0.2600;0.2175]; 
KME_MR_TS       = KME_MR_TS/KME_MR_TS(1);
rms_KME_MR_TS   = rmse(KME_MR_TS);

KME_rms        = [rms_KME_MR_CF;
                 rms_KME_MR_CW;
                 rms_KME_MR_TS]';   
             
%% Knee flexion moment

% Constant force BWS
KMF_MR_CF       = [-0.8575;-0.8188;-0.7700;-0.7275;-0.6800;-0.6213;-0.5712];
KMF_MR_CF       = KMF_MR_CF/KMF_MR_CF(1);
rms_KMF_MR_CF   = rmse(KMF_MR_CF);

% Counterweight BWS
KMF_MR_CW       = [-0.8725;-0.8213;-0.7900;-0.7471;-0.6988;0;-0.5900];
KMF_MR_CW       = KMF_MR_CW/KMF_MR_CW(1);
rms_KMF_MR_CW   = rmse(KMF_MR_CW);

% Tuned spring BWS
KMF_MR_TS       = [-0.8600;-0.8300;-0.7988;-0.7013;-0.6600;-0.6275;-0.6100]; 
KMF_MR_TS       = KMF_MR_TS/KMF_MR_TS(1);
rms_KMF_MR_TS   = rmse(KMF_MR_TS);

KMF_rms        = [rms_KMF_MR_CF;
                 rms_KMF_MR_CW;
                 rms_KMF_MR_TS]';   
             
%% Ankle PF moment

% Constant force BWS
AME_MR_CF       = [1.6800;1.6325;1.5613;1.5100;1.4600;1.4125;1.3388];
AME_MR_CF       = AME_MR_CF/AME_MR_CF(1);
rms_AME_MR_CF   = rmse(AME_MR_CF);

% Counterweight BWS
AME_MR_CW       = [1.6562;1.6287;1.5500;1.4886;1.4425;0;1.3413];
AME_MR_CW       = AME_MR_CW/AME_MR_CW(1);
rms_AME_MR_CW   = rmse(AME_MR_CW);

% Tuned spring BWS
AME_MR_TS       = [1.6813;1.6262;1.5688;1.5425;1.4900;1.4325;1.3550]; 
AME_MR_TS       = AME_MR_TS/AME_MR_TS(1);
rms_AME_MR_TS   = rmse(AME_MR_TS);

AME_rms        = [rms_AME_MR_CF;
                 rms_AME_MR_CW;
                 rms_AME_MR_TS]';         
             
%% Vertical GRF peak I

% Constant force BWS
V1GRF_SLIP_CF     = [1952.7;1869.6;1605.7;1708.5;0;0;0];
V1GRF_SLIP_CF     = V1GRF_SLIP_CF/V1GRF_SLIP_CF(1);
rms_V1GRF_SLIP_CF = rmse(V1GRF_SLIP_CF);
V1GRF_MR_CF       = [13.4075;12.4663;10.7950;10.1313;9.5875;9.0538;8.4750];
V1GRF_MR_CF       = V1GRF_MR_CF/V1GRF_MR_CF(1);
rms_V1GRF_MR_CF   = rmse(V1GRF_MR_CF);

% Counterweight BWS
V1GRF_SLIP_CW     = [1;0;0;0;0;0;0]; % SLIP model did not walk at >0% BWU for the CW system
V1GRF_SLIP_CW     = V1GRF_SLIP_CW/V1GRF_SLIP_CW(1);
rms_V1GRF_SLIP_CW = rmse(V1GRF_SLIP_CW);
V1GRF_MR_CW       = [13.4100;12.2100;10.7087;10.1529;9.7650;0;8.9163];
V1GRF_MR_CW       = V1GRF_MR_CW/V1GRF_MR_CW(1);
rms_V1GRF_MR_CW   = rmse(V1GRF_MR_CW);

% Tuned spring BWS
V1GRF_SLIP_TS     = [1953.4;1882.7;1803.4;1724.7;1642.3;1555.7;1436.7];
V1GRF_SLIP_TS     = V1GRF_SLIP_TS/V1GRF_SLIP_TS(1);
rms_V1GRF_SLIP_TS = rmse(V1GRF_SLIP_TS);
V1GRF_MR_TS       = [13.3625;12.7750;12.1825;10.3013;9.7138;8.9112;8.5187]; 
V1GRF_MR_TS       = V1GRF_MR_TS/V1GRF_MR_TS(1);
rms_V1GRF_MR_TS   = rmse(V1GRF_MR_TS);

V1GRF_rms        = [rms_V1GRF_SLIP_CF,rms_V1GRF_MR_CF;
                    rms_V1GRF_SLIP_CW,rms_V1GRF_MR_CW;
                    rms_V1GRF_SLIP_TS,rms_V1GRF_MR_TS]';
                
%% Vertical GRF peak II

% Constant force BWS
V2GRF_SLIP_CF     = [1939.0;1866.8;1697.8;1707.6;0;0;0];
V2GRF_SLIP_CF     = V2GRF_SLIP_CF/V2GRF_SLIP_CF(1);
rms_V2GRF_SLIP_CF = rmse(V2GRF_SLIP_CF);
V2GRF_MR_CF       = [10.4450;10.1862;9.7588;9.4438;9.1675;8.8575;8.4300];
V2GRF_MR_CF       = V2GRF_MR_CF/V2GRF_MR_CF(1);
rms_V2GRF_MR_CF   = rmse(V2GRF_MR_CF);

% Counterweight BWS
V2GRF_SLIP_CW     = [1;0;0;0;0;0;0]; % SLIP model did not walk at >0% BWU for the CW system
V2GRF_SLIP_CW     = V2GRF_SLIP_CW/V2GRF_SLIP_CW(1);
rms_V2GRF_SLIP_CW = rmse(V2GRF_SLIP_CW);
V2GRF_MR_CW       = [10.2900;10.1413;9.6887;9.3157;8.9963;0;8.4438];
V2GRF_MR_CW       = V2GRF_MR_CW/V2GRF_MR_CW(1);
rms_V2GRF_MR_CW   = rmse(V2GRF_MR_CW);

% Tuned spring BWS
V2GRF_SLIP_TS     = [1950.0;1878.6;1800.3;1720.9;1639.0;1553.6;1461.8];
V2GRF_SLIP_TS     = V2GRF_SLIP_TS/V2GRF_SLIP_TS(1);
rms_V2GRF_SLIP_TS = rmse(V2GRF_SLIP_TS);
V2GRF_MR_TS       = [10.4725;10.1325;9.7925;9.6638;9.3463;8.9813;9.2325]; 
V2GRF_MR_TS       = V2GRF_MR_TS/V2GRF_MR_TS(1);
rms_V2GRF_MR_TS   = rmse(V2GRF_MR_TS);

V2GRF_rms        = [rms_V2GRF_SLIP_CF,rms_V2GRF_MR_CF;
                    rms_V2GRF_SLIP_CW,rms_V2GRF_MR_CW;
                    rms_V2GRF_SLIP_TS,rms_V2GRF_MR_TS]';
                
%% Anteroposterior GRF valley

% Constant force BWS
AP1GRF_MR_CF       = [-3.0388;-3.5088;-2.6025;-2.5375;-2.3913;-2.1888;-1.9600];
AP1GRF_MR_CF       = AP1GRF_MR_CF/AP1GRF_MR_CF(1);
rms_AP1GRF_MR_CF   = rmse(AP1GRF_MR_CF);

% Counterweight BWS
AP1GRF_MR_CW       = [-2.9563;-2.6200;-2.6462;-2.514;-2.3663;0;-1.9513];
AP1GRF_MR_CW       = AP1GRF_MR_CW/AP1GRF_MR_CW(1);
rms_AP1GRF_MR_CW   = rmse(AP1GRF_MR_CW);

% Tuned spring BWS
AP1GRF_MR_TS       = [-3.1038;-2.9625;-2.8362;-2.6513;-2.3962;-2.2036;-2.1813]; 
AP1GRF_MR_TS       = AP1GRF_MR_TS/AP1GRF_MR_TS(1);
rms_AP1GRF_MR_TS   = rmse(AP1GRF_MR_TS);

AP1GRF_rms        = [rms_AP1GRF_MR_CF;
                     rms_AP1GRF_MR_CW;
                     rms_AP1GRF_MR_TS]';   
                 
%% Anteroposterior GRF peak

% Constant force BWS
AP2GRF_MR_CF       = [2.0588;1.6463;1.2800;1.0725;0.9000;0.7600;0.6812];
AP2GRF_MR_CF       = AP2GRF_MR_CF/AP2GRF_MR_CF(1);
rms_AP2GRF_MR_CF   = rmse(AP2GRF_MR_CF);

% Counterweight BWS
AP2GRF_MR_CW       = [2.1400;1.5950;1.2712;1.0800;0.9300;0;0.6000];
AP2GRF_MR_CW       = AP2GRF_MR_CW/AP2GRF_MR_CW(1);
rms_AP2GRF_MR_CW   = rmse(AP2GRF_MR_CW);

% Tuned spring BWS
AP2GRF_MR_TS       = [2.0350;1.8113;1.6125;1.0938;0.9500;0.8025;0.7663]; 
AP2GRF_MR_TS       = AP2GRF_MR_TS/AP2GRF_MR_TS(1);
rms_AP2GRF_MR_TS   = rmse(AP2GRF_MR_TS);

AP2GRF_rms        = [rms_AP2GRF_MR_CF;
                     rms_AP2GRF_MR_CW;
                     rms_AP2GRF_MR_TS]'; 
                 
%% VAS muscle activity

% Constant force BWS
VAS_MR_CF       = [0.0802;0.044;0.0761;0.0675;0.0610;0.0584;0.0523];
VAS_MR_CF       = VAS_MR_CF/VAS_MR_CF(1);
rms_VAS_MR_CF   = rmse(VAS_MR_CF);

% Counterweight BWS
VAS_MR_CW       = [0.0810;0.0763;0.0724;0.0680;0.0600;0;0.0531];
VAS_MR_CW       = VAS_MR_CW/VAS_MR_CW(1);
rms_VAS_MR_CW   = rmse(VAS_MR_CW);

% Tuned spring BWS

VAS_MR_TS       = [0.0738;0.0868;0.0795;0.0861;0.0682;0.0580;0.0566]; 
VAS_MR_TS       = VAS_MR_TS/VAS_MR_TS(1);
rms_VAS_MR_TS   = rmse(VAS_MR_TS);

VAS_rms        = [rms_VAS_MR_CF;
                  rms_VAS_MR_CW;
                  rms_VAS_MR_TS]';
              
%% HAM muscle activity 

% Constant force BWS
HAM_MR_CF       = [0.1278;0.1139;0.0992;0.0892;0.0872;0.0807;0.0723];
HAM_MR_CF       = HAM_MR_CF/HAM_MR_CF(1);
rms_HAM_MR_CF   = rmse(HAM_MR_CF);

% Counterweight BWS
HAM_MR_CW       = [0.1234;0.1157;0.1035;0.0943;0.0887;0;0.0771];
HAM_MR_CW       = HAM_MR_CW/HAM_MR_CW(1);
rms_HAM_MR_CW   = rmse(HAM_MR_CW);

% Tuned spring BWS
HAM_MR_TS       = [0.1155;0.1206;0.1082;0.1097;0.0896;0.0819;0.0707]; 
HAM_MR_TS       = HAM_MR_TS/HAM_MR_TS(1);
rms_HAM_MR_TS   = rmse(HAM_MR_TS);

HAM_rms        = [rms_HAM_MR_CF;
                  rms_HAM_MR_CW;
                  rms_HAM_MR_TS]';

%% GAS muscle activity 

% Constant force BWS
GAS_MR_CF       = [0.1875;0.1875;0.1700;0.1637;0.1531;0.1510;0.1492];
GAS_MR_CF       = GAS_MR_CF/GAS_MR_CF(1);
rms_GAS_MR_CF   = rmse(GAS_MR_CF);

% Counterweight BWS
GAS_MR_CW       = [0.1860;0.1835;0.1770;0.1689;0.1576;0;0.1548];
GAS_MR_CW       = GAS_MR_CW/GAS_MR_CW(1);
rms_GAS_MR_CW   = rmse(GAS_MR_CW);

% Tuned spring BWS
GAS_MR_TS       = [0.1820;0.1781;0.1721;0.1595;0.1564;0.1540;0.1458]; 
GAS_MR_TS       = GAS_MR_TS/GAS_MR_TS(1);
rms_GAS_MR_TS   = rmse(GAS_MR_TS);

GAS_rms        = [rms_GAS_MR_CF;
                  rms_GAS_MR_CW;
                  rms_GAS_MR_TS]';
              
%% TA muscle activity 

% Constant force BWS
TA_MR_CF       = [0.0768;0.0768;0.0745;0.0734;0.0772;0.0782;0.0765];
TA_MR_CF       = TA_MR_CF/TA_MR_CF(1);
rms_TA_MR_CF   = rmse(TA_MR_CF);

% Counterweight BWS
TA_MR_CW       = [0.0784;0.0766;0.0736;0.0741;0.0773;0;0.0823];
TA_MR_CW       = TA_MR_CW/TA_MR_CW(1);
rms_TA_MR_CW   = rmse(TA_MR_CW);

% Tuned spring BWS
TA_MR_TS       = [0.0781;0.0801;0.0790;0.0807;0.0774;0.0774;0.0814]; 
TA_MR_TS       = TA_MR_TS/TA_MR_TS(1);
rms_TA_MR_TS   = rmse(TA_MR_TS);

TA_rms        = [rms_TA_MR_CF;
                  rms_TA_MR_CW;
                  rms_TA_MR_TS]';