%% Results for ground reaction forces (GRF)
%  SW:   Simplest walking model
%  SLIP: Spring-loaded inverted pendulum model
%  MR:   Muslce reflex model
%  Experimental data is used from this repository link: 	
%  http://dx.doi.org/10.1186/s12984-018-0380-0clear all
%  - Salil Apte, 2018

clear all
clc

r1 = [228 26 28]./255; % red    - human experimental data for treadmill healthy group
b1 = [55 126 184]./255;% blue   - human experimental data for overground healthy group
g1 = [77 175 74]./255; % green  - muscle reflex model data
o1 = [255 127 0]./255; % orange - SLIP model data
y1 = [255 255 51]./255;% yellow - simplest walking model data
l1 = [152 78 163]./255;% unused

addpath(genpath('boundedline-pkg/Inpaint_nans'))
addpath(genpath('boundedline-pkg/boundedline'))
addpath(genpath('boundedline-pkg/catuneven'))
addpath(genpath('boundedline-pkg/singlepatch'))
bws = 0:5:80;

%% vertical GRF peak 1
%BWU      = [0        5      10     15     20     25     30     35     40     45  50  55  60  65  70  75  80];

% Model data
V1GRF_SLIP   = [1952.7;1869.6;1605.7;1708.5;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN]; 
V1GRF_SLIP   = V1GRF_SLIP/V1GRF_SLIP(1);
V1GRF_MR     = [13.4075;12.4663;10.7950;10.1313;9.5875;9.0538;8.4750;7.6638;7.1237;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
V1GRF_MR     = V1GRF_MR/V1GRF_MR(1);

% Human experimental data
V1GRF_TH     = [1.0000;0.9628;0.9255;0.8883;0.8511;0.8359;0.8066;0.7772;0.7470;0.6635;0.6250;0.5650;0.5050;0.4450;0.3850;0.3250;NaN];
V1GRF_TH_S   = [0;0.0070;0.0141;0.0211;0.0282;0.0300;0.0409;0.0517;0.0636;0;0;0;0;0;0;0;NaN];
V1GRF_OH     = [1.0000;0.9454;0.8907;0.8355;0.7884;0.7506;0.7128;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
V1GRF_OH_S   = [0;0.0021;0.0041;0.0054;0.0047;0.0014;0.0019;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];

% Calculation of rmse error w.r.t to human experimental data
er_V1GRF_MR_OH = sqrt(immse(V1GRF_OH(2:4),V1GRF_MR(2:4)));
er_V1GRF_MR_TH = sqrt(immse(V1GRF_TH(2:4),V1GRF_MR(2:4)));
er_V1GRF_SLIP_OH = sqrt(immse(V1GRF_OH(2:4),V1GRF_SLIP(2:4)));
er_V1GRF_SLIP_TH = sqrt(immse(V1GRF_TH(2:4),V1GRF_SLIP(2:4)));


figure 
hold on
boundedline(bws,V1GRF_OH,V1GRF_OH_S,'--b',bws, V1GRF_TH,V1GRF_TH_S,'--r','alpha','nan', 'gap')
plot(bws,V1GRF_MR,'-o','color',g1,'linewidth',4,'markersize',10)
plot(bws,V1GRF_SLIP,'-o','color',o1,'linewidth',4,'markersize',10)

grid on
grid minor
axis([0 80 0 1.5])
set(gca,'fontsize',36,'fontname','times')
xticks([0 10 20 30 40 50 60 70 80])
xticklabels({'0', '10', '20', '30', '40', '50', '60', '70', '80'})
ylabel('Vertical GRF - peak I','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')

%% vertical GRF peak 2
%BWU      =    [0        5      10     15     20     25     30     35     40     45  50  55  60  65  70  75  80];

% Model data
V2GRF_SLIP   = [1939.0;1866.8;1697.8;1707.6;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN]; 
V2GRF_SLIP   = V2GRF_SLIP/V2GRF_SLIP(1);
V2GRF_MR     = [10.4450;10.1862;9.7588;9.4438;9.1675;8.8575;8.4300;7.9138;7.4488;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
V2GRF_MR     = V2GRF_MR/V2GRF_MR(1);

% Human experimental data
V2GRF_TH     = [1.0000;0.9581;0.9163;0.8744;0.8325;0.8263;0.7941;0.7618;0.7205;0.6612;0.6094;0.5459;0.4824;0.4188;0.3553;0.2918;NaN];
V2GRF_TH_S   = [0;0.0114;0.0228;0.0342;0.0456;0.0079;0.0060;0.0041;0.0107;0;0;0;0;0;0;0;NaN];
V2GRF_OH     = [1.0000;0.9240;0.8480;0.7929;0.7530;0.7107;0.6685;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
V2GRF_OH_S   = [0;0.0172;0.0344;0.0220;0.0309;0.0430;0.0551;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];

% Calculation of rmse error w.r.t to human experimental data
er_V2GRF_MR_OH = sqrt(immse(V2GRF_OH(2:4),V2GRF_MR(2:4)));
er_V2GRF_MR_TH = sqrt(immse(V2GRF_TH(2:4),V2GRF_MR(2:4)));
er_V2GRF_SLIP_OH = sqrt(immse(V2GRF_OH(2:4),V2GRF_SLIP(2:4)));
er_V2GRF_SLIP_TH = sqrt(immse(V2GRF_TH(2:4),V2GRF_SLIP(2:4)));

figure 
hold on
boundedline(bws,V2GRF_OH,V2GRF_OH_S,'--b',bws, V2GRF_TH,V2GRF_TH_S,'--r','alpha','nan', 'gap')
plot(bws,V2GRF_MR,'-o','color',g1,'linewidth',4,'markersize',10)
plot(bws,V2GRF_SLIP,'-o','color',o1,'linewidth',4,'markersize',10)

grid on
grid minor
axis([0 80 0 1.5])
set(gca,'fontsize',36,'fontname','times')
xticks([0 10 20 30 40 50 60 70 80])
xticklabels({'0', '10', '20', '30', '40', '50', '60', '70', '80'})
ylabel('Vertical GRF - peak II','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')

%% AP GRF valley
%BWU      =     [0        5      10     15     20     25     30     35     40     45  50  55  60  65  70  75  80];

% Model data
AP1GRF_MR     = [-3.0388;-3.5088;-2.6025;-2.5375;-2.3913;-2.1888;-1.9600;-1.6900;-1.6263;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
AP1GRF_MR     = -AP1GRF_MR/AP1GRF_MR(1);

% Human experimental data
AP1GRF_TH     = [-1.0000;-0.9487;-0.8974;-0.8461;-0.7947;-0.7458;-0.7044;-0.6630;-0.6216;-0.7039;-0.6730;NaN;NaN;NaN;NaN;NaN;NaN];
AP1GRF_TH_S   = [0;0.0184;0.0368;0.0552;0.0736;0.1155;0.1304;0.1452;0.1601;0;0;NaN;NaN;NaN;NaN;NaN;NaN];
AP1GRF_OH     = [-1.0000;-0.9215;-0.8431;-0.7379;-0.6518;-0.5836;-0.5154;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
AP1GRF_OH_S   = [0;0.0368;0.0736;0.0726;0.0445;0.0416;0.0387;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];

% Calculation of rmse error w.r.t to human experimental data
er_AP1GRF_MR_OH = sqrt(immse(AP1GRF_OH(2:4),AP1GRF_MR(2:4)));
er_AP1GRF_MR_TH = sqrt(immse(AP1GRF_TH(2:4),AP1GRF_MR(2:4)));


figure 
hold on
boundedline(bws,AP1GRF_OH,AP1GRF_OH_S,'--b',bws, AP1GRF_TH,AP1GRF_TH_S,'--r','alpha','nan', 'gap')
plot(bws,AP1GRF_MR,'-o','color',g1,'linewidth',4,'markersize',10)

grid on
grid minor
axis([0 80 -1.5 0])
set(gca,'fontsize',36,'fontname','times')
xticks([0 10 20 30 40 50 60 70 80])
xticklabels({'0', '10', '20', '30', '40', '50', '60', '70', '80'})
ylabel('Anteroposterior GRF - peak I','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')

%% AP GRF peak
%BWU      = [0        5      10     15     20     25     30     35     40     45  50  55  60  65  70  75  80];

% Model data
AP2GRF_MR     = [2.0588;1.6463;1.2800;1.0725;0.9000;0.7600;0.6812;0.6338;0.6500;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
AP2GRF_MR     = AP2GRF_MR/AP2GRF_MR(1);

% Human experimental data
AP2GRF_TH     = [1.0000;0.9533;0.9066;0.8599;0.8132;0.8207;0.7823;0.7439;0.7055;0.6604;0.6132;NaN;NaN;NaN;NaN;NaN;NaN];
AP2GRF_TH_S   = [0;0.0177;0.0354;0.0532;0.0709;0.0401;0.0277;0.0153;0.0029;0;0;NaN;NaN;NaN;NaN;NaN;NaN];
AP2GRF_OH     = [1.0000;0.9011;0.8022;0.7222;0.6674;0.6444;0.6214;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
AP2GRF_OH_S   = [0;0.0003;0.0006;0.0276;0.0192;0.0559;0.0925;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];

% Calculation of rmse error w.r.t to human experimental data
er_AP2GRF_MR_OH = sqrt(immse(AP2GRF_OH(2:4),AP2GRF_MR(2:4)));
er_AP2GRF_MR_TH = sqrt(immse(AP2GRF_TH(2:4),AP2GRF_MR(2:4)));

figure 
hold on
boundedline(bws,AP2GRF_OH,AP2GRF_OH_S,'--b',bws, AP2GRF_TH,AP2GRF_TH_S,'--r','alpha','nan', 'gap')
plot(bws,AP2GRF_MR,'-o','color',g1,'linewidth',4,'markersize',10)

grid on
grid minor
axis([0 80 0 1.5])
set(gca,'fontsize',36,'fontname','times')
xticks([0 10 20 30 40 50 60 70 80])
xticklabels({'0', '10', '20', '30', '40', '50', '60', '70', '80'})
ylabel('Anteroposterior GRF - peak II','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')