%% Results for muscle activity
%  SW:   Simplest walking model
%  SLIP: Spring-loaded inverted pendulum model
%  MR:   Muslce reflex model
%  Experimental data is used from this repository link: 	
%  http://dx.doi.org/10.1186/s12984-018-0380-0
%  - Salil Apte, 2018

clear all
clc

r1 = [228 26 28]./255; % red    - human experimental data for treadmill healthy group
b1 = [55 126 184]./255;% blue   - human experimental data for overground healthy group
g1 = [77 175 74]./255; % green  - muscle reflex model data
o1 = [255 127 0]./255; % orange - SLIP model data
y1 = [255 255 51]./255;% yellow - simplest walking model data
l1 = [152 78 163]./255;% unused

addpath(genpath('boundedline-pkg/Inpaint_nans'))
addpath(genpath('boundedline-pkg/boundedline'))
addpath(genpath('boundedline-pkg/catuneven'))
addpath(genpath('boundedline-pkg/singlepatch'))
bws = 0:5:80;

%% VAS muscle activity ~ RF muscle in experiment (Quadriceps muscle group)

%BWU      = [0        5      10     15     20     25     30     35     40     45  50  55  60  65  70  75  80];

% Model data
VAS_MR    = [0.0802;0.044;0.0761;0.0675;0.0610;0.0584;0.0523;0.0488;0.0515;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
VAS_MR    = VAS_MR/VAS_MR(1);

% Human experimental data
VAS_TH    = [1.0000;0.9912;0.9823;0.9735;0.9647;0.9472;0.9427;0.9382;0.9257;1.0294;1.0342;1.0425;1.0508;1.0591;1.0674;1.0757;NaN];
VAS_TH_S  = [0;0.0521;0.1042;0.1563;0.2083;0.2639;0.3050;0.3480;0.3784;0.5048;0.5323;0.5506;0.5688;0.5871;0.6053;0.6236;NaN];
VAS_OH    = [1.0000;0.9222;0.8444;0.7889;0.7333;0.7852;0.8370;0.8370;0.8370;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
VAS_OH_S  = [0;0;0;0;0;0;0;0;0;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];

% Calculation of rmse error w.r.t to human experimental data
er_VAS_MR_OH = sqrt(immse(VAS_OH(2:4),VAS_MR(2:4)));
er_VAS_MR_TH = sqrt(immse(VAS_TH(2:4),VAS_MR(2:4)));

figure 
hold on
boundedline(bws,VAS_OH,VAS_OH_S,'--b',bws, VAS_TH,VAS_TH_S,'--r','alpha','nan', 'gap')
plot(bws,VAS_MR,'-o','color',g1,'linewidth',4,'markersize',10)
grid on
grid minor
axis([0 80 0 2])
set(gca,'fontsize',36,'fontname','times')
xticks([0 10 20 30 40 50 60 70 80])
xticklabels({'0', '10', '20', '30', '40', '50', '60', '70', '80'})
ylabel('EMG - Quadriceps','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')

%% HAM muscle activity ~ BF muscle in experiment (Hamstrings muscle group)

%BWU      = [0        5      10     15     20     25     30     35     40     45  50  55  60  65  70  75  80];

% Model data
HAM_MR    = [0.1278;0.1139;0.0992;0.0892;0.0872;0.0807;0.0723;0.0708;0.0627;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
HAM_MR    = HAM_MR/HAM_MR(1);

% Human experimental data
HAM_TH    = [1.0000;1.0111;1.0222;1.0333;1.0443;1.0488;1.0438;1.0388;1.0378;1.1394;1.1517;1.1717;1.1917;1.2117;1.2317;1.2517;NaN];
HAM_TH_S  = [0;0.0163;0.0326;0.0489;0.0652;0.0930;0.1134;0.1351;0.1626;0.0991;0.1279;0.1273;0.1268;0.1262;0.1256;0.1250;NaN];
HAM_OH    = [1.0000;0.9505;0.9009;0.8874;0.8739;0.8694;0.8649;0.8378;0.8108;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
HAM_OH_S  = [0;0;0;0;0;0;0;0;0;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];

% Calculation of rmse error w.r.t to human experimental data
er_HAM_MR_OH = sqrt(immse(HAM_OH(2:4),HAM_MR(2:4)));
er_HAM_MR_TH = sqrt(immse(HAM_TH(2:4),HAM_MR(2:4)));

figure 
hold on
boundedline(bws,HAM_OH,HAM_OH_S,'--b',bws, HAM_TH,HAM_TH_S,'--r','alpha','nan', 'gap')
plot(bws,HAM_MR,'-o','color',g1,'linewidth',4,'markersize',10)
grid on
grid minor
axis([0 80 0 1.5])
set(gca,'fontsize',36,'fontname','times')
xticks([0 10 20 30 40 50 60 70 80])
xticklabels({'0', '10', '20', '30', '40', '50', '60', '70', '80'})
ylabel('EMG - Ham','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')

%% GAS muscle activity ~ MG & LG muscle in experiment 

%BWU      = [0        5      10     15     20     25     30     35     40     45  50  55  60  65  70  75  80];

% Model data
GAS_MR    = [0.1875;0.1875;0.1700;0.1637;0.1531;0.1510;0.1492;0.1444;0.1295;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
GAS_MR    = GAS_MR/GAS_MR(1);

% Human experimental data
GAS_TH_MG    = [1.0000;0.9655;0.9310;0.8965;0.8621;0.8399;0.8096;0.7792;0.7489;0.5834;0.5295;0.5085;0.4874;0.4664;0.4453;0.4242;NaN];
GAS_TH_MG_S  = [0;0.0103;0.0205;0.0308;0.0411;0.0651;0.0960;0.1277;0.1597;0.0723;0.0787;0.0695;0.0645;0.0646;0.0698;0.0791;NaN];
GAS_TH_LG    = [1.0000;0.9618;0.9236;0.8854;0.8473;0.8514;0.8556;0.8597;0.8577;0.6690;0.6226;0.5950;0.5675;0.5399;0.5124;0.4848;NaN];
GAS_TH_LG_S  = [0;0.0059;0.0117;0.0176;0.0234;0.0306;0.0846;0.1386;0.2014;0;0;0;0;0;0;0;NaN];
GAS_OH_LG    = [1.0000;0.9590;0.9180;0.8770;0.7056;0.5342;0.3628;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
GAS_OH_LG_S  = [0;0;0;0;0;0;0;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];

% Calculation of rmse error w.r.t to human experimental data
er_GAS_MR_OH_LG = sqrt(immse(GAS_OH_LG(2:4),GAS_MR(2:4)));
er_GAS_MR_TH_LG = sqrt(immse(GAS_TH_LG(2:4),GAS_MR(2:4)));
er_GAS_MR_TH_MG = sqrt(immse(GAS_TH_MG(2:4),GAS_MR(2:4)));

figure 
hold on
boundedline(bws, GAS_OH_LG,GAS_OH_LG_S,'--b',bws, GAS_TH_LG,GAS_TH_LG_S,'--r',bws, GAS_TH_MG,GAS_TH_MG_S,'--k','alpha','nan', 'gap')
plot(bws,GAS_MR,'-o','color',g1,'linewidth',4,'markersize',10)
grid on
grid minor
axis([0 80 0 1.5])
set(gca,'fontsize',36,'fontname','times')
xticks([0 10 20 30 40 50 60 70 80])
xticklabels({'0', '10', '20', '30', '40', '50', '60', '70', '80'})
ylabel('EMG - Gas','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')

%% TA muscle activity ~ TA muscle in experiment

%BWU      = [0        5      10     15     20     25     30     35     40     45  50  55  60  65  70  75  80];

% Model data
TA_MR    = [0.0768;0.0768;0.0745;0.0734;0.0772;0.0782;0.0765;0.0790;0.0826;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
TA_MR    = TA_MR/TA_MR(1);

% Human experimental data
TA_TH    = [1.0000;0.9988;0.9976;0.9964;0.9952;0.9941;0.9857;0.9774;0.9656;0.9537;0.9419;0.9412;0.9404;0.9397;0.9390;0.9383;NaN];
TA_TH_S  = [0;0.0026;0.0052;0.0079;0.0105;0.0131;0.0196;0.0266;0.0279;0.0296;0.0315;0.0555;0.0796;0.1037;0.1278;0.1519;NaN];
TA_OH    = [1.0000;0.9557;0.9115;0.8416;0.7644;0.7096;0.6548;0.7436;0.7564;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];
TA_OH_S  = [0;0.0263;0.0526;0.0427;0.0432;0.0753;0.1075;0;0;NaN;NaN;NaN;NaN;NaN;NaN;NaN;NaN];

% Calculation of rmse error w.r.t to human experimental data
er_TA_MR_OH = sqrt(immse(TA_OH(2:4),TA_MR(2:4)));
er_TA_MR_TH = sqrt(immse(TA_MR(2:4),TA_TH(2:4)));

figure 
hold on
boundedline(bws, TA_OH,TA_OH_S,'--b',bws, TA_TH,TA_TH_S,'--r','alpha','nan', 'gap')
plot(bws,TA_MR,'-o','color',g1,'linewidth',4,'markersize',10)
grid on
grid minor
axis([0 80 0 1.5])
set(gca,'fontsize',36,'fontname','times')
xticks([0 10 20 30 40 50 60 70 80])
xticklabels({'0', '10', '20', '30', '40', '50', '60', '70', '80'})
ylabel('EMG - TA','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')
